@@ -11,8 +11,11 @@ pub struct Ferium {
     #[clap(subcommand)]
     pub subcommand: SubCommands,
     #[clap(long)]
+    #[clap(help("A GitHub personal access token for increasing the rate limit"))]
+    pub github_token: Option<String>,
+    #[clap(long)]
     #[clap(hide = true)]
-    #[clap(help("Nur zum testen"))]
+    #[clap(help("Only for testing"))]
     pub config_file: Option<PathBuf>,
 }
 
@@ -78,7 +81,7 @@ pub enum ProfileSubCommands {
         #[clap(long)]
         #[clap(arg_enum)]
         #[clap(help("The mod loader to check compatibility for"))]
-        mod_loader: Option<libium::config::structs::ModLoaders>,
+        mod_loader: Option<libium::config::structs::ModLoader>,
         #[clap(long)]
         #[clap(help("The name of the profile"))]
         name: Option<String>,
@@ -97,7 +100,7 @@ pub enum ProfileSubCommands {
         #[clap(long)]
         #[clap(arg_enum)]
         #[clap(help("The mod loader to check compatibility for"))]
-        mod_loader: Option<libium::config::structs::ModLoaders>,
+        mod_loader: Option<libium::config::structs::ModLoader>,
         #[clap(long)]
         #[clap(help("The name of the profile"))]
         name: Option<String>,
